.. module:: enaml.core.declarative

======================
enaml.core.declarative
======================

.. rubric:: Functions

.. autosummary::
    :nosignatures:

    d_


.. rubric:: Classes

.. autosummary::
    :nosignatures:

    Declarative


.. autofunction:: d_

.. autoclass:: Declarative
